import { FaDiscord, FaTelegramPlane, FaFire } from "react-icons/fa";
import {
  RiOpenaiFill,
  RiGeminiLine,
  RiStackOverflowLine,
} from "react-icons/ri";
import { Link } from "react-router-dom";
import Logo from "../ui/Logo";

function Footer() {
  const currentYear = new Date().getFullYear();

  return (
    <footer className="bg-campfire-charcoal py-12 mt-20">
      <div className="container-custom">
        <div className="grid grid-cols-1 md:grid-cols-4 gap-8">
          {/* Brand */}
          <div className="col-span-1 md:col-span-1">
            <Link to="/" className="flex items-center">
              <Logo size="small" />
              <span className="ml-2 text-xl font-bold">CampFire Critics</span>
            </Link>
            <p className="mt-4 text-campfire-ash">
              Делаем хорошо, но на отъебись.
            </p>
            <div className="flex mt-6 space-x-4">
              <a
                href="#"
                className="text-campfire-ash hover:text-campfire-amber"
              >
                <FaDiscord size={20} />
              </a>
              <a
                href="#"
                className="text-campfire-ash hover:text-campfire-amber"
              >
                <FaTelegramPlane size={20} />
              </a>
              <a
                href="#"
                className="text-campfire-ash hover:text-campfire-amber"
              >
                <FaFire size={20} />
              </a>
            </div>
          </div>

          {/* Navigation */}
          <div className="col-span-1">
            <h3 className="text-lg font-semibold mb-4">Атлас</h3>
            <ul className="space-y-2">
              <li>
                <Link
                  to="/"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Главная
                </Link>
              </li>
              <li>
                <Link
                  to="/discover/movies"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Фильмы
                </Link>
              </li>
              <li>
                <Link
                  to="/discover/tv"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Сериалы
                </Link>
              </li>
              <li>
                <Link
                  to="/discover/games"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Игры
                </Link>
              </li>
            </ul>
          </div>

          {/* Legal */}
          <div className="col-span-1">
            <h3 className="text-lg font-semibold mb-4">Правовая информация</h3>
            <ul className="space-y-2">
              <li>
                <Link
                  to="/terms"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Пользовательское соглашение
                </Link>
              </li>
              <li>
                <Link
                  to="/privacy"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Конфиденциальность
                </Link>
              </li>
              <li>
                <Link
                  to="/cookies"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Куки
                </Link>
              </li>
            </ul>
          </div>

          {/* Contact */}
          <div className="col-span-1">
            <h3 className="text-lg font-semibold mb-4">Контакты</h3>
            <ul className="space-y-2">
              <li className="text-campfire-ash">
                <span>general@campfiregg.ru</span>
              </li>
              <li>
                <Link
                  to="/contact"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  Связаться с нами
                </Link>
              </li>
              <li>
                <Link
                  to="/faq"
                  className="text-campfire-ash hover:text-campfire-amber"
                >
                  FAQ
                </Link>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-campfire-dark mt-12 pt-8 text-center text-campfire-ash">
          <p>
            &copy; {currentYear} CampFire Critics. Почти все права защищены.
          </p>
          <p className="mt-2 text-sm">
            <a
              href="#"
              className="text-campfire-ash hover:text-campfire-amber inline-flex items-center"
            >
              VibeCoded with
              <RiStackOverflowLine className="ml-1" size={20} />
              <RiGeminiLine className="ml-1" size={20} />
              <RiOpenaiFill className="ml-1" size={20} />
            </a>
          </p>
        </div>
      </div>
    </footer>
  );
}

export default Footer;
