import {
  Chart as ChartJS,
  RadialLinearScale,
  PointElement,
  LineElement,
  Filler,
  Tooltip,
  Legend
} from 'chart.js';
import { Radar } from 'react-chartjs-2';

// Register ChartJS components
ChartJS.register(
  RadialLinearScale,
  PointElement,
  LineElement,
  Filler,
  Tooltip,
  Legend
);

function RatingChart({ ratings, size = 'medium', showLegend = false }) {
  // Default ratings if none provided
  const defaultRatings = {
    story: 0,
    visuals: 0,
    performance: 0,
    soundtrack: 0,
    enjoyment: 0
  };

  // Merge provided ratings with defaults
  const mergedRatings = { ...defaultRatings, ...ratings };
  
  // Chart data
  const data = {
    labels: ['Story', 'Visuals', 'Performance', 'Soundtrack', 'Enjoyment'],
    datasets: [
      {
        label: 'Rating',
        data: [
          mergedRatings.story,
          mergedRatings.visuals,
          mergedRatings.performance,
          mergedRatings.soundtrack,
          mergedRatings.enjoyment
        ],
        backgroundColor: 'rgba(255, 157, 0, 0.2)',
        borderColor: 'rgba(255, 157, 0, 1)',
        borderWidth: 1,
        pointBackgroundColor: 'rgba(255, 157, 0, 1)',
        pointBorderColor: '#fff',
        pointHoverBackgroundColor: '#fff',
        pointHoverBorderColor: 'rgba(255, 69, 0, 1)',
      }
    ]
  };

  // Chart options
  const options = {
    scales: {
      r: {
        angleLines: {
          display: true,
          color: 'rgba(255, 255, 255, 0.1)',
        },
        suggestedMin: 0,
        suggestedMax: 10,
        ticks: {
          stepSize: 2,
          backdropColor: 'transparent',
          color: 'rgba(255, 255, 255, 0.7)',
        },
        grid: {
          color: 'rgba(255, 255, 255, 0.1)',
        },
        pointLabels: {
          color: 'rgba(255, 255, 255, 0.7)',
          font: {
            size: size === 'small' ? 8 : 12,
          },
        },
      }
    },
    plugins: {
      legend: {
        display: showLegend,
      },
      tooltip: {
        backgroundColor: 'rgba(45, 55, 72, 0.9)',
        titleColor: '#ffffff',
        bodyColor: '#ffffff',
        bodyFont: {
          size: 14,
        },
        titleFont: {
          size: 16,
          weight: 'bold',
        },
        padding: 10,
        displayColors: false,
        callbacks: {
          label: function(context) {
            return `Rating: ${context.raw}/10`;
          }
        }
      }
    },
    elements: {
      line: {
        tension: 0.2
      }
    },
    responsive: true,
    maintainAspectRatio: true,
  };

  // Size classes
  const sizeClasses = {
    small: 'w-32 h-32',
    medium: 'w-64 h-64',
    large: 'w-96 h-96'
  };

  return (
    <div className={`${sizeClasses[size]} mx-auto`}>
      <Radar data={data} options={options} />
    </div>
  );
}

export default RatingChart;